==> jc-1.4.0.tar.gz: soot/ErroneousType.h <==
// public class soot.ErroneousType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f411a963f5c51a62 soot_ErroneousType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_ErroneousType_H_
#define _JC_soot_ErroneousType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_ErroneousType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_ErroneousType$sub_refs	_jc_soot_ErroneousType$sub_refs;
typedef struct _jc_soot_ErroneousType$sub_nonrefs	_jc_soot_ErroneousType$sub_nonrefs;
typedef struct _jc_soot_ErroneousType$refs	_jc_soot_ErroneousType$refs;
typedef struct _jc_soot_ErroneousType$nonrefs	_jc_soot_ErroneousType$nonrefs;
typedef struct _jc_soot_ErroneousType$object	_jc_soot_ErroneousType$object;

typedef const struct _jc_soot_ErroneousType$vmethods	_jc_soot_ErroneousType$vmethods;
typedef const struct _jc_soot_ErroneousType$vtable	_jc_soot_ErroneousType$vtable;
typedef const struct _jc_soot_ErroneousType$vtype	_jc_soot_ErroneousType$vtype;

// Constructors
extern void _jc_soot_ErroneousType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_ErroneousType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_object *);
extern jboolean _jc_soot_ErroneousType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_ErroneousType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_ErroneousType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_ErroneousType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_ErroneousType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_ErroneousType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_ErroneousType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_ErroneousType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_ErroneousType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_ErroneousType$object *_jc_soot_ErroneousType$method$v$b489c3249de2f45f(_jc_env *);

// Virtual methods structure
struct _jc_soot_ErroneousType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_ErroneousType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_ErroneousType$object *);
};

// Vtable
struct _jc_soot_ErroneousType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_ErroneousType$vmethods	soot_ErroneousType;
};

// Vtype
struct _jc_soot_ErroneousType$vtype {
	_jc_type			type;
	_jc_soot_ErroneousType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_ErroneousType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_ErroneousType$refs {
    _jc_soot_ErroneousType$sub_refs	soot_ErroneousType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_ErroneousType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_ErroneousType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_ErroneousType$sub_nonrefs	soot_ErroneousType;
};

// Object instance structure
struct _jc_soot_ErroneousType$object {
	_jc_soot_ErroneousType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_ErroneousType$vtype	*vtype;
	_jc_soot_ErroneousType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_ErroneousType$vtype _jc_soot_ErroneousType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_ErroneousType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_ErroneousType$class_object;

#endif	/* _JC_soot_ErroneousType_H_ */

==> jc-1.4.6.tar.gz: soot/ErroneousType.h <==
// public class soot.ErroneousType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f411a963f5c51a62 soot_ErroneousType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_ErroneousType_H_
#define _JC_soot_ErroneousType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_ErroneousType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_ErroneousType$sub_refs	_jc_soot_ErroneousType$sub_refs;
typedef struct _jc_soot_ErroneousType$sub_nonrefs	_jc_soot_ErroneousType$sub_nonrefs;
typedef struct _jc_soot_ErroneousType$refs	_jc_soot_ErroneousType$refs;
typedef struct _jc_soot_ErroneousType$nonrefs	_jc_soot_ErroneousType$nonrefs;
typedef struct _jc_soot_ErroneousType$object	_jc_soot_ErroneousType$object;

typedef const struct _jc_soot_ErroneousType$vmethods	_jc_soot_ErroneousType$vmethods;
typedef const struct _jc_soot_ErroneousType$vtable	_jc_soot_ErroneousType$vtable;
typedef const struct _jc_soot_ErroneousType$vtype	_jc_soot_ErroneousType$vtype;

// Constructors
extern void _jc_soot_ErroneousType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_ErroneousType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_ErroneousType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_ErroneousType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_ErroneousType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_ErroneousType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_ErroneousType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_ErroneousType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_ErroneousType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_ErroneousType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_ErroneousType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_ErroneousType$object *_jc_soot_ErroneousType$method$v$b489c3249de2f45f(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_ErroneousType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_ErroneousType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_ErroneousType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_ErroneousType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_ErroneousType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_ErroneousType$vmethods	soot_ErroneousType;
};

// Vtype
struct _jc_soot_ErroneousType$vtype {
	_jc_type			type;
	_jc_soot_ErroneousType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_ErroneousType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_ErroneousType$refs {
    _jc_soot_ErroneousType$sub_refs	soot_ErroneousType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_ErroneousType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_ErroneousType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_ErroneousType$sub_nonrefs	soot_ErroneousType;
};

// Object instance structure
struct _jc_soot_ErroneousType$object {
	_jc_soot_ErroneousType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_ErroneousType$vtype	*vtype;
	_jc_soot_ErroneousType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_ErroneousType$vtype _jc_soot_ErroneousType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_ErroneousType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_ErroneousType$class_object;

#endif	/* _JC_soot_ErroneousType_H_ */
